@@ -1,5 +1,5 @@
 class Game:
-    def __init__(self, players, game_map, played_at, game_length, events, protocol):
+    def __init__(self, players, game_map, played_at, game_length, events, protocol, gamedata):
         self.players = players
         self.map = game_map
         self.played_at = played_at
@@ -8,4 +8,6 @@ class Game:
         self.events = events
         self.state = []
         self.timeline = []
+        self.engagements = []
         self.protocol = protocol
+        self.gamedata = gamedata
